# WhereDoIHaveAnAccount Third Party Dependencies

WhereDoIHaveAnAccount depends on third party libraries to implement some functionality. This document describes which libraries WDIHAA depends on. This is a best effort attempt to describe the library's dependencies, it is subject to change as libraries are added/removed.

| Name       | URL                                      | License              |
|------------|------------------------------------------|----------------------|
| pytest     | https://github.com/pytest-dev/pytest     | MIT license          |
| tox        | https://github.com/tox-dev/tox           | MIT license          |
| imap-tools | https://github.com/ikvk/imap_tools       | Apache-2.0 license   |
| setuptools | https://github.com/pypa/setuptools       | MIT license          |
| requests   | https://github.com/psf/requests          | Apache-2.0 license   |